==> zhongyan-manage-service-api-3.0.16-sources.jar: cn/com/duiba/cloud/manage/service/api/remoteservice/tag/RemoteZYTagValueService.java <==
package cn.com.duiba.cloud.manage.service.api.remoteservice.tag;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.manage.service.api.model.dto.tag.TagValueUserDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.tag.ZYTagValueDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.terminal.PageRetailerDTO;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.RemoteManageRetailerPageParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteAddTagValueParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteCancelAllConnectParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteDelTagValueParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteQueryConnectParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteTagUserListParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteTagValuePageQueryParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.RemoteUpdateTagValueParam;
import cn.com.duiba.wolf.entity.PageResponse;

import java.util.List;

/**
 * @author wangxukai
 * @description
 * @date ：Created in 2022/3/2
 */
@AdvancedFeignClient
public interface RemoteZYTagValueService {


    /**
     * 增加标签值
     * @param param
     * @return
     */
    Long addTagValue(RemoteAddTagValueParam param) throws BizException;

    /**
     * 更新标签值
     * @param param
     * @return
     */
    Boolean updateTagValue(RemoteUpdateTagValueParam param) throws BizException;

    /**
     * 删除标签值
     * @param param
     * @return
     */
    Boolean delTagValue(RemoteDelTagValueParam param);

    /**
     * 查询标签值列表
     * @param param
     * @return
     */
    PageResponse<ZYTagValueDto> queryList(RemoteTagValuePageQueryParam param);


    /**
     * 用户打/取消标签
     * @param param
     * @return
     */
    Boolean tagUserList(RemoteTagUserListParam param);


    /**
     * 取消所有用户关联
     * @param param
     * @return
     */
    Boolean cancelAllConnect(RemoteCancelAllConnectParam param);

    /**
     * 查询关联
     * @param param
     * @return
     */
    List<TagValueUserDto> queryConnectList(RemoteQueryConnectParam param);

    /**
     * 根据名称查询
     * @param name
     * @return
     */
    List<ZYTagValueDto> queryByNamePrefix(String name);

    /**
     * 根据id列表查询标签值
     * @param valueIdList
     * @param isDelete 能否查看被删除的
     * @return
     */
    List<ZYTagValueDto> queryByIdList(List<Long> valueIdList,Boolean isDelete);

    /**
     * 查询用户已关联的标签
     * @param userIdList 用户id list
     * @return List<TagValueUserDto>
     */
    List<TagValueUserDto> queryByUserIdList(List<Long> userIdList);

    /**
     * 根据id列表查询用户关联的标签
     * @param valueIdList 标签id list
     * @return List<TagValueUserDto>
     */
    List<TagValueUserDto> queryConnectByIdList(List<Long> valueIdList);

    /**
     * 判断用户是否在标签列表中
     * @param userId 用户id
     * @param valueIdList 标签值id list
     * @return true 表示存在
     */
    boolean judgeInTagList(Long userId, List<Long> valueIdList);

    /**
     * 分页查询零售户 id list
     * @param param 查询参数
     * @return List<Long>
     */
    List<PageRetailerDTO> pageRetailer(RemoteManageRetailerPageParam param);

    /**
     * 统计零售户数量
     * @param param 查询参数
     * @return 零售户数量
     */
    Long countRetailer(RemoteManageRetailerPageParam param);
}

==> zhongyan-manage-service-api-3.0.39-20230712.071454-10-sources.jar: cn/com/duiba/cloud/manage/service/api/remoteservice/tag/RemoteZYTagValueService.java <==
package cn.com.duiba.cloud.manage.service.api.remoteservice.tag;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.manage.service.api.model.dto.tag.TagValueUserDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.tag.ZYTagValueDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.terminal.PageRetailerDTO;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.RemoteManageRetailerPageParam;
import cn.com.duiba.cloud.manage.service.api.model.param.tag.value.*;
import cn.com.duiba.wolf.entity.PageResponse;

import java.util.List;

/**
 * @author wangxukai
 * @description
 * @date ：Created in 2022/3/2
 */
@AdvancedFeignClient
public interface RemoteZYTagValueService {


    /**
     * 增加标签值
     * @param param
     * @return
     */
    Long addTagValue(RemoteAddTagValueParam param) throws BizException;

    /**
     * 更新标签值
     * @param param
     * @return
     */
    Boolean updateTagValue(RemoteUpdateTagValueParam param) throws BizException;

    /**
     * 删除标签值
     * @param param
     * @return
     */
    Boolean delTagValue(RemoteDelTagValueParam param);

    /**
     * 查询标签值列表
     * @param param
     * @return
     */
    PageResponse<ZYTagValueDto> queryList(RemoteTagValuePageQueryParam param);


    /**
     * 用户打/取消标签
     * @param param
     * @return
     */
    Boolean tagUserList(RemoteTagUserListParam param);


    /**
     * 取消所有用户关联
     * @param param
     * @return
     */
    Boolean cancelAllConnect(RemoteCancelAllConnectParam param);

    /**
     * 查询关联
     * @param param
     * @return
     */
    List<TagValueUserDto> queryConnectList(RemoteQueryConnectParam param);

    /**
     *  分页查询
     * @param remoteQueryConnectPageParam
     * @return
     */
    PageResponse<TagValueUserDto> queryConnectListPage(RemoteQueryConnectPageParam remoteQueryConnectPageParam);

    /**
     * 根据名称查询
     * @param name
     * @return
     */
    List<ZYTagValueDto> queryByNamePrefix(String name);

    /**
     * 根据id列表查询标签值
     * @param valueIdList
     * @param isDelete 能否查看被删除的
     * @return
     */
    List<ZYTagValueDto> queryByIdList(List<Long> valueIdList,Boolean isDelete);

    /**
     * 查询用户已关联的标签
     * @param userIdList 用户id list
     * @return List<TagValueUserDto>
     */
    List<TagValueUserDto> queryByUserIdList(List<Long> userIdList);

    /**
     * 根据id列表查询用户关联的标签
     * @param valueIdList 标签id list
     * @return List<TagValueUserDto>
     */
    List<TagValueUserDto> queryConnectByIdList(List<Long> valueIdList);

    /**
     * 判断用户是否在标签列表中
     * @param userId 用户id
     * @param valueIdList 标签值id list
     * @return true 表示存在
     */
    boolean judgeInTagList(Long userId, List<Long> valueIdList);

    /**
     * 分页查询零售户 id list
     * @param param 查询参数
     * @return List<Long>
     */
    List<PageRetailerDTO> pageRetailer(RemoteManageRetailerPageParam param);

    /**
     * 统计零售户数量
     * @param param 查询参数
     * @return 零售户数量
     */
    Long countRetailer(RemoteManageRetailerPageParam param);
}
